@@ -1,9 +1,9 @@
 
 #' @title Arrange entries in data.frame
 #' @description Analogous function for \code{arrange} in \pkg{dplyr}.
-#' @param data data.frame
-#' @param ... List of variables or name-value pairs of summary/modifications
-#'   functions.
+#' @param .data data.frame
+#' @param ... Arrange by what group? Minus symbol means arrange by
+#' descending order.
 #' @return data.table
 #' @seealso \code{\link[dplyr]{arrange}},\code{\link[maditr]{dt_arrange}}
 #' @examples
@@ -19,16 +19,9 @@
 
 #' @export
 
-arrange_dt = function(data,...){
-  dt = as_dt(data)
+arrange_dt = function(.data,...){
+  dt = as_dt(.data)
   dt[order(...)]
 }
 
-# arrange_dt = function(data,...){
-#   dt = as_dt(data)
-#   substitute(list(...)) %>%
-#     deparse() %>%
-#     str_extract("\\(.+\\)") %>%
-#     str_sub(2,-2)-> dot_string
-#   eval(parse(text = str_glue("dt[order({dot_string})]")))
-# }
+
