@@ -1,7 +1,7 @@
 
 #' @title Pull out a single variable
 #' @description Analogous function for \code{pull} in \pkg{dplyr}
-#' @param data data.frame
+#' @param .data data.frame
 #' @param col A name of column or index (should be positive).
 #' @return vector
 #' @seealso \code{\link[dplyr]{pull}}
@@ -12,8 +12,8 @@
 #' @export
 
 
-pull_dt = function(data,col){
-  dt = as_dt(data)
+pull_dt = function(.data,col){
+  dt = as_dt(.data)
   dt[[substitute(col)]]
 }
 
