@@ -1,12 +1,12 @@
 
 #' @title Select column from data.frame
 #' @description Analogous function for \code{select} and \code{select_if} in \pkg{dplyr}.
-#' @param data data.frame
+#' @param .data data.frame
 #' @param ... List of variables or name-value pairs of summary/modifications
 #'   functions. It can also recieve conditional function to select columns.
 #'   When starts with `-`(minus symbol) or `!`, return the negative columns.
 #' @param cols (Optional)A numeric or character vector.
-#' @param negate Applicable when regular expression is used.
+#' @param negate Applicable when regular expression and "cols" is used.
 #' If \code{TRUE}, return the non-matched pattern. Default uses \code{FALSE}.
 #' @param rm.dup Should duplicated columns be removed? Defaults to \code{TRUE}.
 #' @return data.table
@@ -30,6 +30,7 @@
 #' iris %>% select_dt("Pe",negate = TRUE)
 #' iris %>% select_dt("Pe|Sp")
 #' iris %>% select_dt(cols = 2:3)
+#' iris %>% select_dt(cols = 2:3,negate = TRUE)
 #' iris %>% select_dt(cols = names(iris)[2:3])
 #'
 #' iris %>% select_dt(is.factor)
@@ -46,14 +47,16 @@
 #' @rdname select
 #' @export
 
-select_dt = function(data,...,cols = NULL,negate =FALSE){
-  dt = as_dt(data)
+select_dt = function(.data,...,cols = NULL,negate =FALSE){
+  dt = as_dt(.data)
   if(is.null(cols)){
     substitute(list(...)) %>%
       deparse() %>% paste0() %>%
       str_extract("\\(.+\\)") %>%
       str_sub(2,-2)-> dot_string
     if(is.na(dot_string)) dt
+    else if(str_detect(dot_string,"^[-,0-9 ]+$"))
+      eval(parse(text = str_glue("dt[,c({dot_string})]")))
     else if(str_detect(dot_string,"^[-!]?\"")){
       if(dot_string %like% "^[-!]") {
         dot_string = str_remove(dot_string,"^-|^!")
@@ -64,8 +67,6 @@ select_dt = function(data,...,cols = NULL,negate =FALSE){
         str_c(collapse = ",") -> dot_string
       eval(parse(text = str_glue("dt[,.({dot_string})]")))
     }
-    else if(str_detect(dot_string,"[0-9]$")& str_detect(dot_string,"^-|^[0-9]"))
-      eval(parse(text = str_glue("dt[,c({dot_string})]")))
     else if(str_detect(dot_string,"^c\\(")|str_count(dot_string,":") == 1)
       eval(parse(text = str_glue("dt[,{dot_string}]")))
     else if(dot_string %like% "^[-!]?is\\.")
@@ -81,11 +82,14 @@ select_dt = function(data,...,cols = NULL,negate =FALSE){
     }
     else eval(parse(text = str_glue("dt[,.({dot_string})]")))
   }
-  else dt[,.SD,.SDcols = cols]
+  else {
+    if(!negate) dt[,.SD,.SDcols = cols]
+    else eval(dt[, .SD,.SDcols = !cols])
+  }
 }
 
-select_if_dt = function(data,.if){
-  dt = as_dt(data)
+select_if_dt = function(.data,.if){
+  dt = as_dt(.data)
   if_name = substitute(.if) %>% deparse()
   if(str_detect(if_name,"^-")){
     .if = str_remove(if_name,"-")
@@ -99,8 +103,8 @@ select_if_dt = function(data,.if){
 
 #' @rdname select
 #' @export
-select_mix = function(data,...,rm.dup = TRUE){
-  dt = as_dt(data)
+select_mix = function(.data,...,rm.dup = TRUE){
+  dt = as_dt(.data)
 
   substitute(list(...)) %>%
     lapply(deparse) %>%
