@@ -3,7 +3,7 @@
 #' @description Performs the opposite operation to `dplyr::count()`,
 #'  duplicating rows according to a weighting variable (or expression).
 #'  Analogous to `tidyr::uncount`.
-#' @param data A data.frame
+#' @param .data A data.frame
 #' @param wt A vector of weights.
 #' @param .remove Should the column for \code{weights} be removed?
 #' Default uses \code{TRUE}.
@@ -15,8 +15,8 @@
 #' uncount_dt(df,n,FALSE)
 #' @export
 
-uncount_dt = function(data,wt,.remove = TRUE){
-  dt = as_dt(data)
+uncount_dt = function(.data,wt,.remove = TRUE){
+  dt = as_dt(.data)
   if(.remove) eval(substitute(dt[rep(1:.N,wt)][,wt:=NULL][]))
   else eval(substitute(dt[rep(1:.N,wt)]))
 }
